# What is it?

ds_helpers is a Python package providing common helper functions for quick data analysis and modeling. Now you can simply call the helper functions for repetitive work and focus on other important things in your Data Science project.

# Where to get it

The source code is currently hosted on GitHub at: <https://github.com/shashankwadhwa9/ds-helpers>

Binary installers for the latest released version are available at the Python package index.

    pip install ds_helpers

# License
[MIT](https://github.com/shashankwadhwa9/ds-helpers/blob/master/LICENSE)
